/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This function, focusOnPopUp, traps all mouse clicks on the page, and when our
 * custom pop-up window is "open", it determines if the click was on the pop-up
 * window or elsewhere on the page. When the mouse click is not on the pop-up
 * window, the event is stopped and the focus is returned to the pop-up window.
 * Otherwise, the focus goes where it was intended and the event carries on as
 * usual.
 *
 * @param {Event} e The event that has fired in the browser.
 */
function focusOnPopUp(e) {
	/*
	 * This is the cross-browser way of getting the target of the event in
	 * question.
	 */
	var el = ((e.target) ? e.target : e.srcElement);

	/* Is our pop-up window currently active? */
	if (Element.visible('popupContainer')) {
		/* Is the event target our pop-up window? */
		if (el.id != 'popupContainer') {
			var childNode = false;

			/*
			 * Walk the DOM and find out if this element is a child of the
			 * /popupContainer/
			 */
			for (var child = el.parentNode; child.tagName != 'BODY'; child = child.parentNode)
				/* Is the target element a childNode of the pop-up container? */
				if (child.id == 'popupContainer') {
					childNode = true;
					break;
				}
			/* Is the event part of our pop-up window? */
			if (!childNode) {
				Event.stop(e);
				$('btnOk').focus( );
			/* Give the event target focus, since it is part of the pop-up window */
			} else
				el.focus( );
		}
	/* Give the event target focus, since the pop-up window is not active */
	} else
		el.focus( );
}