/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This function, onConfirmOkay, is the handler for an onclick event on the OK
 * button of a confirmation window. It makes an XMLHttpRequest, passing to the
 * server some predetermined data, reporting back to the user if there is a
 * failure; otherwise, it provides some other functionality.
 *
 * @return Returns false, so the form is not actually submitted.
 * @type Boolean
 */
function onConfirmOkay( ) {
	/*
	 * Make sure that the confirmation data that we wish to send to the server is
	 * actually there.
	 */
	if (!$F('confirmedData'))
		$('confirmedData').value = '001 - Bad confirmation received from user.';
	new Ajax.Request('saveConfirm.php', {
		method: 'post',
		parameters: 'data=' + $F('confirmData'),
		onSuccess: function(xhrResponse) {
			/* Do something here */
		},
		onFailure: function(xhrResponse) {
			/* Send the error message to the user */
			fillPopUp('There was an internal error with the application: <br />' + xhrResponse.statusText);
		}
	});
	/* "Close" the confirmation window after the Ajax request has gone out */
	closeConfirm( );
	return (false);
}

/**
 * This function, onConfirmCancel, is the handler for an /onclick/ event on the
 * Cancel button of a confirmation window. It closes the confirmation window after
 * clearing out whatever input was to be confirmed.
 *
 * @return Returns false, so the form is not actually submitted.
 * @type Boolean
 */
function onConfirmCancel( ) {
	/* Clear out the input box being confirmed */
	$('confirmedData').value = '';
	/* "Close" the confirmation window so the user can do something else */
	closeConfirm( );
	return (false);
}

/* Open up a confirmation window */
var confirmationQuestion = 'Are you sure you want to leave this page before you have completed all of your answers to this test?';
fillConfirmation(confirmationQuestion, 'Are you sure you want to leave?');

/**
 * This function, fillConfirmation, takes the data that is passed to it in the
 * /p_data/ parameter and sets it equal to the /innerHTML/ of the confirmation
 * window's content container, and the data that is passed in the /p_header/
 * parameter and sets it equal to the /innerHTML/ of the confirmation window's
 * handle text. It then "opens" the confirmation window.
 *
 * @param {String} p_data The string containing the data to set to the pop-up
 * 		element's /innerHTML/.
 * @param {String} p_header The string containing the pop-up element's "header".
 */
function fillConfirmation(p_data, p_header) {
	if (p_header)
		$('handleConfirmText').innerHTML = p_header;
	else
		$('handleConfirmText').innerHTML = 'Alert window';
	$('confirmContent').innerHTML = p_data;
	/*
	 * This is for Internet Explorer in case the p_data passed in contained event
	 * attributes, just to make sure that they fire correctly for the user.
	 */
	$('confirmContent').innerHTML = $('confirmContent').innerHTML;
	/* "Open" up the confirmation window for the user to see. */
	showConfirm( );
}