/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This is the global prompt variable that can be accessed by the application at
 * any time.
 */
var promptInputData = '';

/**
 * This function, onPromptOkay, is the handler for an onclick event on the OK
 * button of a prompt window. It sets a variable that is accessible to the rest of
 * the application.
 *
 * @return Returns false, so the form is not actually submitted.
 * @type Boolean
 */
function onPromptOkay( ) {
	/* Make sure that the prompt data that we wish to set is actually there */
	if (!$F('promptData')) {
		promptInputData = '';
		/* Set up a new event for the information window */
		try {
			Event.observe($('btnOk'), 'click', firstPrompt( ), false);
		} catch (ex) {}
			fillPrompt('You did not fill anything in the input field.', 'There was a problem');
	} else {
		/* Set our global variable to the user's input */
		promptInputData = $F('promptData');
		/* Clean up after ourselves for the next use */
		$('promptData').value = '';
	}
	/* "Close" the prompt window after the Ajax request has gone out */
	closePrompt( );
	return (false);
}

/**
 * This function, onPromptCancel, is the handler for an /onclick/ event on the
 * Cancel button of a prompt window. It closes the prompt window after clearing
 * out whatever input was prompted for.
 *
 * @return Returns false, so the form is not actually submitted.
 * @type Boolean
 */
function onPromptCancel( ) {
	/* Clear out the input box being prompted for */
	$('promptData').value = '';
	promptInputData = '';
	/* "Close" the pop-up window so the user can do something else */
	closePopUp( );
	return (false);
}

/**
 * This function, firstPrompt, is the handler for the page load, and for re-
 * prompting the user if there is an issue with any previous prompt. It calls the
 * prompt window.
 */
function firstPrompt( ) {
	fillPrompt('What should we call you?', 'Name, please...');
}

/**
 * This function, fillPrompt, takes the data that is passed to it in the /p_data/
 * parameter and sets it equal to the /innerHTML/ of the prompt window's content
 * container, and the data that is passed in the /p_header/ parameter and sets it
 * equal to the /innerHTML/ of the prompt window's handle text. It then "opens"
 * the prompt window.
 *
 * @param {String} p_data The string containing the data to set to the pop-up
 * 		element's /innerHTML/.
 * @param {String} p_header The string containing the pop-up element's "header".
 */
function fillPrompt(p_data, p_header) {
	if (p_header)
		$('handlePromptText').innerHTML = p_header;
	else
		$('handlePromptText').innerHTML = 'Alert window';
	$('promptContent').innerHTML = p_data;
	/*
	 * This is for Internet Explorer in case the p_data passed in contained event
	 * attributes, just to make sure that they fire correctly for the user.
	 */
	$('promptContent').innerHTML = $('promptContent').innerHTML;
	/* "Open" up the prompt window for the user to see. */
	showPrompt( );
}