/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */

/* Example 11-2. A simple style-switching object. */

/**
 * This object, StyleSwitcher, contains all of the functionality to get and set an
 * alternative style chosen by the user from a list provided by the application. It
 * contains the following methods:
 * - setActive(p_title)
 * - getActive( )
 */
var StyleSwitcher = {
	/**
	 * This method, setActive, takes the passed /p_title/ variable and sets the
	 * appropriate alternate stylesheet as the current enabled one.
	 *
	 * @param {String} p_title The title that is to be set as active.
	 * @member StyleSwitcher
	 * @return Returns false so that the click event will be ignored.
	 * @type Boolean
	 */
	setActive: function(p_title) {
		/* Get a list of the <link> elements in the document */
		var links = document.getElementsByTagName('link');

		/*
		 * Loop through the list, setting the appropriate <link> elements to
		 * disabled, and set the <link> element with the title attribute equal to
		 * /p_title/ to active.
		 */
		for (var i = links.length; i > 0;) {
			/* Get the current <link> element */
			var iLink = links[i--];

			/* Is this element an appropriate stylesheet to mark? */
			if (iLink.getAttribute('rel').indexOf('style') != -1 && iLink.getAttribute('title')) {
				iLink.disabled = true;
				/* Is this element the one we are looking for? */
				if (iLink.getAttribute('title') == p_title)
					iLink.disable = false;
			}
		}
		/* Set the cookie to the passed /p_title/ variable, and do not let it expire
		 * for one year.
		 */
		Cookie.set('appStyle', p_title, 365);
		return (false);
	},
	/**
	 * This method, getActive, returns the current active stylesheet node (<link>
	 * element) in the document, provided that there is one to return.
	 *
	 * @member StyleSwitcher
	 * @return Returns the active stylesheet node, if one exists.
	 * @type Node
	 */
	getActive: function( ) {
		/* Get a list of the <link> elements in the document */
		var links = document.getElementsByTagName('link');

		/*
		 * Loop through the list until the active stylesheet is located, then
		 * return it.
		 */
		for (var i = links.length; i > 0;) {
			/* Get the current link element */
			var iLink = links[i--];

			/* Is this the currently active <link> element? */
			if (iLink.getAttribute('rel').indexOf('style') != -1 && iLink.getAttribute('title') && !iLink.disabled)
				return (iLink.getAttribute('title'));
		}
		return (null);
	}
};