<?php
/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * Example 12-1, A custom error handler for PHP
 *
 * This example shows how to create a custom error handler to receive any
 * application script error that may appear within the PHP script. All PHP error
 * handlers need to receive four parameters:
 * 		the error number, the error message, the file the error occurred in, and the
 * 		line the error occurred on.
 */
	
/* Set the error reporting levels for this script */
error_reporting(E_ERROR | E_WARNING | E_NOTICE);

/**
 * This function, customErrorHandler, is a custom error handler replacement for the
 * default error handler used by PHP.
 *
 * @param integer $p_error_num the error number
 * @param string $p_error_str the error message string
 * @param string $p_error_file the file the error occurred on
 * @param integer $p_err_line the line the error occurred on
 */
function customErrorHandler($p_error_num, $p_error_str, $p_error_file, $p_err_line) {
	switch ($p_error_num) {
		case E_ERROR:
			print("<b>Custom ERROR</b> [$p_error_num] $p_error_str<br />\n");
			print(" Fatal error on line $p_err_line in file $p_error_file");
			print(', PHP '.PHP_VERSION.' ('.PHP_OS.')<br />\n');
			exit(1);
			break;
		case E_WARNING:
			print("<b>Custom WARNING</b> [$p_error_num] $p_error_str<br />\n");
			break;
		case E_NOTICE:
			print("<b>Custom NOTICE</b> [$p_error_num] $p_error_str<br />\n");
			break;
		default:
			print("Unknown error type: [$p_error_num] $p_error_str<br />\n");
			break;
	}
}

/* Set the error handling to the user-defined custom error handler */
$php_error_handler = set_error_handler('customErrorHandler');
?>