/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/*
 * Example 14-14. An example of the client handling a complex server response.
 */

/**
 * This method, handleXMLResponse, takes the /xhrResponse/'s responseXML and
 * parses it, placing the necessary elements in the correct place within the
 * DOM document. This function handles any JavaScript needed on the page as
 * well, eval'ing it after the page content has loaded.
 *
 * @param {Object} xhrResponse The XMLHttpRequest response from the server.
 * @return Returns true so that nothing ever stops processing because of this.
 * @type Boolean
 */
function handleXMLResponse(xhrResponse) {
	try {
		/* Get a list of any errors returned from the server */
		var errors = xhrResponse.responseXML.getElementsByTagName('error');

		/* Were any errors returned? */
		if (errors.length > 0) {
			/*
			 * This variable, errorMessages, will contain the error messages to
			 * be shown to the user
			 */
			var errorMessages = '';

			/* Loop through all of the errors */
			for (var i = 0, il = errors.length; i < il; i++)
				errorMessages += 'ERROR: ' + errors[i].firstChild.nodeValue + '\n';
			alert(errorMessages);
			return (true);
		}
	} catch (ex) { /* This is just in case something odd happened */ }

	try {
		/* Get the separate elements from the server response */
		var pageTitle = xhrResponse.responseXML.getElementsByTagName('title')[0];
		var pageBody = xhrResponse.responseXML.getElementsByTagName('body')[0];
		var pageScripting = xhrResponse.responseXML.getElementsByTagName('scripts')[0];

		/* Was a page title returned? */
		if (pageTitle)
			$('pageTitle').innerHTML = pageTitle;
		/* Was new page content returned? */
		if (pageBody)
			$('pageContent').innerHTML = pageBody;
		/* Were any JavaScripts returned that need eval'ing? */
		if (pageScripting)
			/*
			 * This is potentially dangerous, and uses something like the
			 * parseJSON() method found at http://www.json.org/json.js.
			 */
			eval(pageScripting);
		return (true);
	} catch (ex) {
		alert('There was a problem on the server processing your request.');
		return (true);
	}
}