<?php
/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * Example 16-2. Performing a full text search using PHP.
 */

/* The starting place of the site */
$dir = '/root/of/site';
/* This will hold the results of the parse */
$results = array( );

/**
 * This function, parse_meta_elements, searches through the passed /p_dir/ and
 * searches all of the files (of an acceptable type) for the passed
 * /p_search_string/, recursively searching subdirectories and building a
 * results array to report its findings.
 *
 * @param {String} $p_dir The directory to search for files to parse in.
 * @param {String} $p_search_string The string to search for in the files.
 */
function parse_meta_elements($p_dir, $p_search_string) {
	/* Could we open up a handle to the passed directory? */
	if ($dh = @opendir($p_dir)) {
		/* Loop through the files in the directory */
		while (($file = readdir($dh)) !== false) {
			/* The file is not '.', is it? */
			if (!preg_match('/^\./s', $file))
				/* Is the current file a directory? */
				if (is_dir($p_dir.$file)) {
					$newdir = $p_dir.$file.'/';
					chdir($newdir);
					/* Recursive traversal */
					parse_meta_elements($newdir, $p_search_string);
				} else
					/* Is the file a type we want to parse? */
					if (preg_match('/^\.(php)|(html)|(txt)/', $file))
						/* Can we get a handle on the file? */
						if ($handle = @fopen($file, 'r')) {
							$hits = 0;
							/* Parse the file */
							while (!eof($handle)) {
								$buffer = fgets($handle, 4096);
								/* Get a count of matches for ranking */
								$hits += stristr($buffer, $p_search_string);
							}
							$results[] = array(0 => $hits, 1 => $file);
						}
		}
		chdir('..');
	}
}

parse_meta_elements($dir, $_REQUEST['searchString']);

/* Handle the results of the parse here... */
?>