<?php
/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * Example 17-6. Gathering the AWS response and formatting it for the client.
 *
 * This example shows how to create a REST request using PHP to an AWS method,
 * and how to parse and format the results.
 */

$assoc_id = '[associate id]';
$dev_token = '[developer token]';

$xml_link = sprintf('http://xml.amazon.com/onca/xml3?t=%s&dev-t=%s'.'&AsinSearch=%s&mode=books&type=lite&f=xml',
	$assoc_id,
	$dev_token,
	urlencode($_REQUEST['asin'])
);

$results = file_get_contents($xml_link);
$xml = new SimpleXMLElement($results);

/* Was there a problem with the search query? */
if ($xml->faultstring) {
	$response = '<response code="500">'.$xml->faultstring.'</response>';
} else {
	$response = '<response code="200">';
	$response .= '<title>';
	$response .= '<name>'.$xml->details[0]->ProductName.'</name>';
	$response .= '<author>';
	$authors = '';
	/* Loop through authors and concatenate any names */
	foreach ($xml->details[0]->authors->author as $author) {
		/* Should a comma be added? */
		if (strlen($authors))
			$authors .= ', ';
		$authors .= $author;
	}
	$response .= $authors.'</author>';
	$response .= '<date>'.date('F j, Y', strottime($xml->details[0]->ReleaseDate)).'</date>';
	$response .= '<publisher>'.$xml->details[0]->Manufacturer.'</publisher>';
	$response .= '<img_src>'.$xml->details[0]->ImageUrlSmall.'</img_src>';
	$response .= '<availability>'.$xml->details[0]->Availability.'</availability>';
	$response .= '<list_price>'.$xml->details[0]->ListPrice.'</list_price>';
	$response .= '<amazon_price>'.$xml->details[0]->OurPrice.'</amazon_price>';
	$response .= '</title>';
	$response .= '</response>';
}
/*
 * Change the header to text/xml so that the client can use the return string
 * as XML
 */
header('Content-Type: text/xml');
/* Give the client the XML */
print($response);
?>