<?php
/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * Example 18-1. Calling the FeedBurner MgmtAPI's Find Feeds method using PHP.
 *
 * This file is just a simple example of fetching data using REST and parsing
 * the results.  Much more could be done on the server side, especially if part
 * of a mashup, in this script.
 */

/**
 * The file, user.inc, contains the username and password for the REST request.
 */
require_once('user.inc');
/**
 * This is the PEAR HTTP:Request library used to make our request.
 */
require_once('HTTP/Request.php');

/* Set up the request */
$request =& new HTTP_Request("http://api.feedburner.com/management/"."1.0/FindFeeds?user=$username&password=$password");
$request->addHeader('Accept', 'application/atom+xml');

/* Get the results of the request */
$results = $request->sendRequest();

/* Begin the response text */
$response = '<?xml version="1.0" encoding="utf-8"?>';

/* Was there a problem with the request? */
if (PEAR::isError($results))
	$response .= '<response code="500">'.$response->getMessage( ).'</response>';
else {
	$code = $request->getResponseCode();
	$response .= '<response code="'.$code.'">';
	$xml = new SimpleXMLElement($results);

	/* We can check for whatever codes we want here */
	switch ($code) {
		case 200:
			/* Were there any feeds? */
			if ($xml->children()) {
				$response .= '<feeds>';
				/* Loop through the feeds */
				foreach ($xml->children() as $feed) {
					$response .= '<feed>';
					$response .= "<title>{$feed['title']}</title>";
					$response .= "<link>{$feed['uri']}</link>";
					$response .= '</feed>';
				}
				$response .= '</feeds>';
			} else
				$response .= '<feeds />';
			break;
		default:
			$response .= '<feeds />';
			break;
	}
	$response .= '</response>';
}
/*
 * Change the header to text/xml so that the client can use the return string
 * as XML
 */
header('Content-Type: text/xml');
/* Give the client the XML */
print($response);
?>