/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/*
 * Example 18-5. Parsing a response from YouTube and putting the results into an
 * XHTML application.
 */

/**
 * This function, getYouTubeResults, takes the /xhrResponse/'s responseXML and
 * parses it, placing the necessary elements into the output string that will be
 * the /innerHTML/ of /someElement/.
 *
 * @param {Object} p_xhrResponse The XMLHttpRequest response from the server.
 * @return Returns whether the results were obtained correctly.
 * @type Boolean
 */
function getYouTubeResults(p_xhrResponse) {
	try {
		/* Get all of the video elements from the response */
		var videos = p_xhrResponse.responseXML.getElementsByTagName('video');
		var output = '';

		/* Loop through the video elements and format the output */
		for (var i = 0, il = videos.length; i < il; i++) {
			output += '<div class="youTubeContainer">';
			output += '<div class="youTubeTitle">' + videos[i].getElementsByTagName('title')[0].nodeValue + '</div>';
			output += '<div class="youTubeThumb"><a href="' + videos[i].getElementsByTagName('url')[0].nodeValue +
				'"><img src="' + videos[i].getElementsByTagName('thumbnail_url')[0].nodeValue +
				'" alt="' + videos[i].getElementsByTagName('title')[0].nodeValue +
				'" title="' + videos[i].getElementsByTagName('title')[0].nodeValue +
				'" /></a></div>';
			output += '<div class="youTubeDescription">' + videos[i].getElementsByTagName('description')[0].nodeValue + '</div>';
			output += '</div>';
		}
		/* Place the output in the document */
		$('someElement').innerHTML = output;
		/* Return true, indicating the function executed correctly */
		return (true);
	} catch (ex) {
		/* There was a problem retrieving video, let the user know and return false */
		$('someElement').innerHTML = 'There was an error getting the YouTube videos.';
		return (false);
	}
}
