/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */

/**
 * This variable, POINT_SIZE, is the size of the pen drawing on the canvas.
 */
var POINT_SIZE = 1;
/**
 * This variable, POINT_COLOR, is the color of the pen drawing on the canvas.
 */
var POINT_COLOR = '#f00';

/**
 * This variable, whiteBoard, will be the instantiation of the jsGraphics class.
 */
var whiteBoard = null;

/* Do all this when the page is done loading... */
Event.observe(window, 'load', function( ) {
	/* Create a new canvas to use for the whiteboard */
	whiteBoard = new jsGraphics('whiteBoard');
	/* Set the initial color of the pen */
	whiteBoard.setColor(POINT_COLOR);
	/* Set the initial size of the pen */
	whiteBoard.setStroke(POINT_SIZE);
	/* Set up events to trap mouse events that occur on the /whiteBoard/ */
	Event.observe('whiteBoard', 'mousedown', StartDrawing);
	Event.observe('whiteBoard', 'mouseup', StopDrawing);
});

/**
 * This function, StartDrawing, is called whenever there is a /mousedown/
 * event on the whiteboard, and starts drawing on the canvas.
 *
 * @param {Object} e The current trapped event.
 */
function StartDrawing(e) {
	/* Did the event actually happen on the whiteboard? */
	if (Event.element(e).id == 'whiteBoard')
		DrawPoint(Event.pointerX(e), Event.pointerY(e));
	Event.observe('whiteBoard', 'mousemove', ContinueDrawing);
}

/**
 * This function, StopDrawing, is called whenever there is a /mouseup/
 * event on the whiteboard, and stops all drawing on the canvas.
 *
 * @param {Object} e The current trapped event.
 */
function StopDrawing(e) {
	/* Stop observing /mousemove/ on the board and reset the last coordinates */
	Event.stopObserving('whiteBoard', 'mousemove', ContinueDrawing);
	lastPointX = -1;
	lastPointY = -1;
}

/**
 * This function, ContinueDrawing, is called as long as there is a
 * /mousemove/ event on the whiteboard, and draws on the canvas.
 *
 * @param {Object} e The current trapped event.
 */
function ContinueDrawing(e) {
	/* Did the event actually happen on the whiteboard? */
	if (Event.element(e).id == 'whiteBoard')
		DrawPoint(Event.pointerX(e), Event.pointerY(e));
}