/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/*
 * Example 20-4.  chatting.js: All of the JavaScript code necessary to run a
 * simple Ajax chat client
 */

/* call this when the page is done loading */
Event.observe(window, 'load', StartClient);

/*
 * This variable, g_message, will control the interval for getting messages
 * from the server
 */
var g_message = 0;

/**
 * This function, StartClient, adds events to controls on the page.
 */
function StartClient( ) {
	/* has the username been passed? */
	if ($F('username') != '') {
		Event.observe('loginForm', 'submit', SendMessage);
		Event.observe('submitButton', 'click', SendMessage);
		Event.observe('quitButton', 'click', QuitChat);
		new Ajax.PeriodicalUpdater('usernameContainer', 'get_users.php', {
			method: 'post',
			parameters: { username: $F('username') },
			frequency: .5
		});
		g_message = setInterval(AjaxDisplayMessages, 500);
	}
}

/* This variable, g_lastTime, keeps track of the last request for new messages */
var g_lastTime = 0;
/* This variable, g_onCall, tracks whether there already is a request going or not */
var g_onCall = false;

/**
 * This function, AjaxDisplayMessages, checks the server for messages it has
 * in queue since the last time it was queried and adds new messages to the top
 * of the message container.
 */
function AjaxDisplayMessages( ) {
	/* is there already a request going? */
	if (!g_onCall) {
		g_onCall = true;
		/* make a new request to the server for messages it has in its queue */
		new Ajax.Request('get_messages.php', {
			method: 'post',
			parameters: { username: $F('username'), lasttime: g_lastTime },
			onSuccess: function (p_xhrResponse) {
				/* put the new messages on top */
				new Insertion.Bottom('messageCenter', p_xhrResponse.responseText);
				var d = new Date( );
				/* change the time of the last request */
				g_lastTime = d.getTime( );
				g_onCall = false;
			},
			onFailure: function( ) {
				new Insertion.Bottom('messageCenter', '<p class="errorMessage">ERROR: Could not retrieve messages.</p>');
				g_onCall = false;
			}
		});
	}
}

/**
 * This function, SendMessage, sends the text taken from the text box to
 * the server to be inserted in the messages queue.
 *
 * @param {Object} e The event object that triggered this event.
 */
function SendMessage(e) {
	/* do not let the event continue beyond this point */
	Event.stop(e);
	var d = new Date( );
	/* make an Ajax request to the server with the new message */
	new Ajax.Request('put_message.php', {
		method: 'post',
		parameters: {
			username: $F('username'),
			message: $F('text2Chat'),
			lasttime: d.getTime( )
		},
		onSuccess: function(p_xhrResponse) {
			$('text2Chat').value = '';
			/* was the send unsuccessful? */
			if (p_xhrResponse.responseText != 1)
				new Insertion.Bottom('messageCenter', '<p class="errorMessage">ERROR: Could not send message.</p>');
		},
		onFailure: function( ) {
			$('text2Chat').value = '';
			new Insertion.Bottom('messageCenter', '<p class="errorMessage">ERROR: Could not send message.</p>');
		}
	});
}

/**
 * This function, QuitChat, logs the passed /username/ off of the chat client.
 *
 * @param {Object} e The event object that triggered this event */
 */
function QuitChat(e) {
	Event.stop(e);
	/*
	 * Make an Ajax request to log the user out and take the user back to
	 * the login page
	 */
	new Ajax.Request('logout.php', {
		method: 'post',
		parameters: { username: $F('username') },
		onSuccess: function( ) {
			window.location = 'index.html';
		},
		onFailure: function( ) {
			window.location = 'index.html';
		}
	});
}