/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This variable, __INFORM_START__, is intended as a constant for event start
 * information.
 */
var __INFORM_START__ = 0;
/**
 * This variable, __INFORM_STOP__, is intended as a constant for event stop
 * information.
 */
var __INFORM_STOP__ = 1;
/**
 * This variable, __INFORM_MOVE_CHANGE__, is intended as a constant for event
 * movement change
 * information.
 */
var __INFORM_MOVE_CHANGE__ = 2;
/**
 * This variable, __INFORM_COLLISION__, is intended as a constant for event
 * collision information.
 */
var __INFORM_COLLISION__ = 3;

/**
 * This object, Events, is the container for all events that should be sent to the
 * server and received from the server for the game.
 */
var Events = {
	/**
	 * This member, _URL, is the URL for sending events to the server, and
	 * receiving data from the server.
	 * @private
	 */
	_URL: 'handleEvents.php',
	/**
	 * This method, InformStart, sends information to the server about the start
	 * event for the character.
	 *
	 * @member Events
	 * @param {Integer} p_egoId The id that the server gives to the player when starting.
	 * @param {Integer} p_dir The direction the character will be moving in.
	 * @param {Array} p_coords The coordinates the character started from.
	 */
	InformStart: function(p_egoId, p_dir, p_coords) {
		new Ajax.Request(_URL, {
			method: 'post',
			parameters: {
				type: __INFORM_START__,
				id: p_egoId,
				mouse: false,
				dir: p_dir,
				x: p_coords[0],
				y: p_coords[1]
			}
		});
	},
	/**
	 * This method, InformStartMouse, sends information to the server about the
	 * start event for the character.
	 *
	 * @member Events
	 * @param {Integer} p_egoId The id that the server gives to the player when starting.
	 * @param {Array} p_coordsFrom The x,y coordinates the character started from.
	 * @param {Array} p_coordsTo The x,y coordinates the character is moving to.
	 */
	InformStartMouse: function(p_egoId, p_coordsFrom, p_coordsTo) {
		new Ajax.Request(_URL, {
			method: 'post',
			parameters: {
				type: __INFORM_START__,
				id: p_egoId,
				mouse: true,
				xF: p_coordsFrom[0],
				yF: p_coordsFrom[1],
				xT: p_coordsTo[0],
				yT: p_coordsTo[1]
			}
		});
	},
	/**
	 * This method, InformStop, sends information to the server about the stop
	 * event for the character.
	 *
	 * @member Events
	 * @param {Integer} p_egoId The id that the server gives to the player when stopping.
	 * @param {Array} p_coords The coordinates the character stopped at.
	 */
	InformStop: function(p_egoId, p_coords) {
		new Ajax.Request(_URL, {
			method: 'post',
			parameters: {
				type: __INFORM_STOP__,
				id: p_egoId,
				x: p_coords[0],
				y: p_coords[1]
			}
		});
	}
};