/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This object, Events, is the container for all events that should be sent to
 * the server and received from the server for the game.
 */
var Events = {
	//.
	//.
	//.
	/**
	 * This method, PollServer, sends a request to the server for data the
	 * client needs to receive to update itself.
	 *
	 * @member Events
	 */
	PollServer: function() {
		new Ajax.Request('pollServer.php', {
			method: 'post',
			parameters: { id: ego.getId() },
			onSuccess: Events.ParseServerData
		});
	},
	/**
	 * This method, ParseServerData, parses the commands that the server
	 * responds with for each request the server makes.
	 *
	 * @member Events
	 * @param {Object} p_xhrResponse The server response to the Ajax request.
	 */
	ParseServerData: function(p_xhrResponse) {
		var response = p_xhrResponse.responseXML;
		var players = response.getElementsByTagName('players');

		/* Loop through the player data needed for updating */
		for (var i = 0, il = players.childNodes.length; i < il; i++) {
			var id = players.childNodes[i].getAttribute('id');
			var pos = players.childNodes[i].getAttribute('pos');
			var mouse = players.childNodes[i].getAttribute('mouse');
			var to = null;
			var dir = null;
			/* Is this a mouse movement? */
			if (mouse)
				to = players.childNodes[i].getAttribute('coordsTo');
			else
				dir = players.childNodes[i].getAttribute('dir');

			pos = pos.split(,);
			/* Are there two coordinates? */
			if (to)
				to = to.split(,);
			Events.UpdatePosition(id, pos, to, dir);
		}
	},
	/**
	 * This method, UpdatePosition, updates the position of a player from the
	 * player array with the new information passed to it.
	 *
	 * @member Events
	 * @param {Integer} p_id The index for the player array.
	 * @param {Array} p_pos The current position of the player.
	 * @param {Array} p_to The position to move the player toward.
	 * @param {Integer} p_dir The direction to move the player in.
	 */
	UpdatePosition: function(p_id, p_pos, p_to, p_dir) {
		player[p_id].setPosition(p_pos[0], p_pos[1]);
		/* Are there two coordinates? */
		if (p_to)
			player[p_id].moveCharacterMouse(p_to[0], p_to[1]);
		else
			player[p_id].moveCharacter(p_dir);
	}
};
