/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
var Logic = {
	Bresenham: function(p_x1, p_y1, p_x2, p_y2) {
		var deltaX = Math.abs(p_x2 - p_x1) << 1;
		var deltaY = Math.abs(p_y2 - p_y1) << 1;
		/*
		 * If p_x1 == p_x2 or p_y1 == p_y2, then it makes no difference what
		 * is set here
		 */
		var ix = ((p_x2 > p_x1) ? 1 : -1);
		var iy = ((p_y2 > p_y1) ? 1 : -1);
		var path = [];
		var i = 0;

		/* Which way is the line going to slope? */
		if (deltaX >= deltaY) {
			/* Error may go below zero */
			var error = deltaY - (deltaX >> 1);

			/* Loop until the points are connected */
			while (p_x1 != p_x2) {
				/* Is there a chance the line must shift? */
				if (error >= 0)
					/* Do we need to slide over? */
					if (error || (ix > 0)) {
						p_y1 += iy;
						error -= deltaX;
					}
				p_x1 += ix;
				error += deltaY;
				path[i++] = [p_x1, p_y1];
			}
		} else {
			/* Error may go below zero */
			var error = deltaX - (deltaY >> 1);

			/* Loop until the points are connected */
			while (p_y1 != p_y2) {
				/* Is there a chance the line must shift? */
				if (error >= 0)
					/* Do we need to slide over? */
					if (error || (iy > 0)) {
						p_x1 += ix;
						error -= deltaY;
					}
				p_y1 += iy;
				error += deltaX;
				path[i++] = [p_x1, p_y1];
			}
		}
		return (path);
	},
	RectangularCollisionDetect: function(p_box1, p_box2) {
		/* Is there a vertical collision between the boxes? */
		if ((p_box1[0][0] < p_box2[1][0]) && (p_box1[1][0] > p_box2[0][0]))
			/* Is there a horizontal collision between the boxes? */
			if ((p_box1[0][1] < p_box2[1][1]) && (p_box1[1][1] > p_box2[0][1]))
				return (true);
		return (false);
	},
	CircularCollisionDetect: function(p_point, p_center, p_r2) {
		var r2 = Math.pow((p_point[0] - p_center[0]), 2) + Math.pow((p_point[1] - p_center[1]), 2);

		/* Is there a collision between the circle and point? */
		if (r2 < p_r2)
			return (true);
		return (false);
	},
	LinearCollisionDetect(p_line1, p_line2) {
		var denom = ((p_line2[1][1] - p_line2[0][1]) * (p_line1[1][0] - p_line1[0][0])) - ((p_line2[1][0] - p_line2[0][0]) * (p_line1[1][1] - p_line1[0][1]));
		var numA = ((p_line2[1][0] - p_line2[0][0]) * (p_line1[0][1] - p_line2[0][1])) - ((p_line2[1][1] - p_line2[0][1]) * (p_line1[0][0] - p_line2[0][0]));
		var numB = ((p_line1[1][0] - p_line1[0][0]) * (p_line1[0][1] - p_line2[0][1])) - ((p_line1[1][1] - p_line1[0][1]) * (p_line1[0][0] - p_line2[0][0]));

		/* Are the lines parallel? */
		if (!denom) {
			/* Are the lines on top of each other? */
			if (!numA && !numB)
				return (true);
			return (false);
		}

		var uA = numA / denom;
		var uB = numB / denom;

		/* Is there an intersection? */
		if (uA >= 0 && uA <= 1 && uB >= 0 && uB <= 1)
			return (true);
		return (false);
	}
};