/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
var __PULSE_MOVEMENT__ = 10;

var __MOVE_BACKWARD__ = 0;
var __MOVE_RIGHT__ = 1;
var __MOVE_FORWARD__ = 2;
var __MOVE_LEFT__ = 3;

var character = Class.create();
character.prototype = {
	 _handle: null,
	animation: {
		_options: {
			sprite: null,
			pauseTime: 0
		},
		_currentFrame: 0,
		_spriteFrame: 0,
		_internalTimer: null,
		advanceFrame: function() {
			/* Has the animation reached the last image? */
			if (this._currentFrame == this._options.sprite[this._spriteFrame].frames)
				this._currentFrame = 0;
			this._handle.setStyle({
				backgroundPosition: (-1 * this._options.sprite[this._spriteFrame].frameSize * this._currentFrame) + 'px ' + (-1 * this._options.[this._spriteFrame].spriteSize * this._spriteFrame) + 'px'
			});
			this._currentFrame++;
		},
		startAnimation: function(p_direction) {
			if (p_direction > this._options.sprite.length)
				return (false);
			this._spriteFrame = p_direction;
			this._internalTimer = setInterval(this.advanceFrame.bind(this), this._options.pauseTime);
			return (this._intervalTimer);
		},
		pauseAnimation: function() {
			clearInterval(this._internalTimer.bind(this));
			/* Has the timer been cleared? */
			if (!this._internalTimer) {
				this._internalTimer = null;
				return (true);
			}
			return (false);
		},
		stopAnimation: function() {
			clearInterval(this._internalTimer.bind(this));
			/* Has the timer been cleared? */
			if (!this._internalTimer) {
				this._internalTimer = null;
				this._spriteFrame = 0;
				this._currentFrame = 0;
				this._handle.setStyle({
					backgroundPosition: '0 0'
				});
				return (true);
			}
			return (false);
		}
	},
	initialize: function (p_handle, p_options) {
		this._handle = $(p_handle);
		Object.extend(this.animation._options, p_options || {});
	},
	startAnimation: function(p_direction) {
		return (this.animation.startAnimation(p_direction));
	},
	pauseAnimation: function() {
		return (this.animation.pauseAnimation());
	},
	stopAnimation: function() {
		return (this.animation.stopAnimation());
	},
	movement: {
		_direction: -1,
		_moving: false,
		_position: [0, 0],
		_path: [],
		_internalTimer: null,
		changeDirection: function(p_direction) {
			/* Should the character be stopped? */
			if (this._moving && this._direction == p_direction) {
				this.stop();
				return (false);
			}
			this._direction = p_direction;
			/* Do we need to start the character? */
			if (!this._moving)
				this.start( );
			Event.InformMovementChange(character.prototype.getId.call(this), this._direction, this._position);
			return (true);
		},
		start: function() {
			this._internalTimer = setInterval(this.move.bind(this), __PULSE_MOVEMENT__);
			this._moving = true;
			character.prototype.startAnimation.call(this);
			Event.InformStart(character.prototype.getId.call(this), this._direction, this._position);
			return (this._intervalTimer);
		},
		changeDirectionMouse: function(p_x, p_y) {
			/* Should the character be stopped? */
			if (this._moving)
				this.stop();
			this._direction = -1;
			this._path = Logic.Bresenham(this._position[0], this._position[1], p_x, p_y);
			this.startMouse(p_x, p_y);
			Event.InformMovementChangeMouse(character.prototype.getId.call(this), this._position, [p_x, p_y]);
			return (true);
		},
		startMouse: function(p_x, p_y) {
			this._internalTimer = setInterval(this.moveMouse.bind(this), __PULSE_MOVEMENT__);
			this._moving = true;
			Event.InformStartMouse(character.prototype.getId.call(this), this._position, [p_x, p_y]);
			return (this._intervalTimer);
		},
		stop: function() {
			clearInterval(this._internalTimer.bind(this));
			/* Has the timer been cleared? */
			if (!this._internalTimer) {
				this._internalTimer = null;
				this._moving = false;
				character.prototype.stopAnimation.call(this);
				Event.InformStop(character.prototype.getId.call(this), this._position);
				return (true);
			}
			return (false);
		},
		move: function() {
			switch (this._direction) {
				case __MOVE_BACKWARD__:
					this._position[1] -= 2;
					break;
				case __MOVE_RIGHT__:
					this._position[0] += 2;
					break;
				case __MOVE_FORWARD__:
					this._position[1] += 2;
					break;
				case __MOVE_LEFT__:
					this._position[0] -= 2;
					break;
			}
			this.position();
		},
		moveMouse: function() {
			var point = this._path.shift();
			this._position[0] = point[0];
			this._position[1] = point[1];
			this.position( );
		},
		position: function() {
			this._handle.setStyle({
				left: this._position[0] + 'px',
				top: this._position[1] + 'px'
			});
		},
		setPosition: function(p_x, p_y) {
			this._position[0] = p_x;
			this._position[1] = p_x;
			this.position();
		}
	},
	moveCharacter: function(p_direction) {
		try {
			this.movement.changeDirection(p_direction);
		} catch (ex) {
			alert('Illegal argument sent to method character.moveCharacter():', ex.description);
		}
	},
	moveCharacterMouse: function(p_x, p_y) {
		try {
			this.movement.changeDirectionMouse(p_x, p_y);
		} catch (ex) {
			alert('Illegal argument sent to method character.moveCharacterMouse():', ex.description);
		}
	},
	setPosition: function(p_x, p_y) {
		this.movement.setPosition(p_x, p_y);
	},
	collision: {
		_boundings: [],
		SetBounding: function(p_points) {
			try {
				this._bounding[0] = [p_points[0][0], p_points[0][1]];
				this._bounding[1] = [p_points[1][0], p_points[1][1]];
			} catch (ex) {
				this._bounding = null;
			}
		},
		GetBoundX: function(p_corner) {
			/* Does the character have a bounding box? */
			if (this._bounding)
				return (this._bounding[p_corner - 1][0]);
			return (null);
		},
		GetBoundY: function(p_corner) {
			/* Does the character have a bounding box? */
			if (this._bounding)
				return (this._bounding[p_corner - 1][1]);
			return (null);
		},
		GetBoundingBox() {
			/* Does the character have a bounding box? */
			if (this._bounding)
				return ([[this._bounding[0]], this._bounding[1]]);
			return (null);
		}
	},
	GetBoundX: function(p_corner) {
		return (this.collision.GetBoundX(p_corner));
	},
	GetBoundY: function(p_corner) {
		return (this.collision.GetBoundY(p_corner));
	},
	GetBoundingBox: function( ) {
		return (this.collision.GetBoundingBox());
	},
	TestCollision: function(p_box) {
		if (Logic.RectangularCollisionDetect(this.GetBoundingBox(), p_box.box)) {
			Event.InformCollision(character.prototype.getId.call(this), p_box.id, this._position);
			return (true);
		}
		return (false);
	},
	stats: {
		_id: -1,
		setId: function(p_id) {
			this._id = p_id;
		},
		getId: function() {
			return(this._id);
		}
	},
	setId: function(p_id) {
		this.stats.setId(p_id);
	},
	getId: function() {
		return (this.stats.getId());
	}
};