/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This class, character, will store all of the functionality needed by a
 * character in the game, including animation, movement, and statistics.
 */
var character = Class.create();
character.prototype = {
.
.
.
	animation: {
		/**
		 * This member, _options, holds all of the developer-definable options
		 * for the animation portion of the character class.
		 * @private
		 */
		_options: {
			/**
			 * This member, sprite, is an array of objects that contains the
			 * number of frames per sprite, the size of a frame, and the size
			 * of a sprite.
			 */
			sprite: null,
			/**
			 * This member, pauseTime, stores the length of time that the
			 * animation should pause between "frames" in milliseconds.
			 */
			pauseTime: 0
		},
.
.
.
		/**
		 * This method, advanceFrame, changes the position of the background
		 * image of the /_handle/ based on the /_currentFrame/, /frameSize/,
		 * /spriteSize/, /_spriteCount/, and /_spriteFrame/.
		 *
		 * @member animation
		 */
		advanceFrame: function() {
			/* Has the animation reached the last image? */
			if (this._currentFrame == this._options.sprite[this._spriteFrame].frames)
				this._currentFrame = 0;
			this._handle.setStyle({
				backgroundPosition: (-1 * this._options.sprite[this._spriteFrame].frameSize * this._currentFrame) + 'px ' + (-1 * this._options.[this._spriteFrame].spriteSize * this._spriteFrame) + 'px'
			});
			this._currentFrame++;
		},
		/**
		 * This method, startAnimation, calls the DOM function /setInterval/ to
		 * start the timer for the animation and will report its success.
		 *
		 * @member animation
		 * @param {Integer} p_direction The offset for the necessary sprite of the character.
		 * @return Whether or not the animation was started.
		 * @type Boolean
		 */
		startAnimation: function(p_direction) {
			if (p_direction > this._options.sprite.length)
				return (false);
			this._spriteFrame = p_direction;
			this._internalTimer = setInterval(this.advanceFrame.bind(this), this._options.pauseTime);
			return (this._intervalTimer);
		},
.
.
.