/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This object, Logic, is the container for all mathematical logic functionality
 * for the game.
 */
var Logic = {
	//.
	//.
	//.
	/**
	 * This method, LinearCollisionDetect, tests for a collision (intersection)
	 * between the two passed line segments.
	 *
	 * @member Logic
	 * @param {Array} p_line1 The first line segment for the test.
	 * @param {Array} p_line2 The second line segment for the test.
	 * @return Whether or not the two line segments intersect, or collide.
	 * @type Boolean
	 */
	LinearCollisionDetect(p_line1, p_line2) {
		var denom = ((p_line2[1][1] - p_line2[0][1]) * (p_line1[1][0] - p_line1[0][0])) - ((p_line2[1][0] - p_line2[0][0]) * (p_line1[1][1] - p_line1[0][1]));
		var numA = ((p_line2[1][0] - p_line2[0][0]) * (p_line1[0][1] - p_line2[0][1])) - ((p_line2[1][1] - p_line2[0][1]) * (p_line1[0][0] - p_line2[0][0]));
		var numB = ((p_line1[1][0] - p_line1[0][0]) * (p_line1[0][1] - p_line2[0][1])) - ((p_line1[1][1] - p_line1[0][1]) * (p_line1[0][0] - p_line2[0][0]));

		/* Are the lines parallel? */
		if (!denom) {
			/* Are the lines on top of each other? */
			if (!numA && !numB)
				return (true);
			return (false);
		}

		var uA = numA / denom;
		var uB = numB / denom;

		/* Is there an intersection? */
		if (uA >= 0 && uA <= 1 && uB >= 0 && uB <= 1)
			return (true);
		return (false);
	}
};