<?php
/* 
 * This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This file, output.php, handles all of the functionality that concerns itself
 * with the output being sent to the client.
 */

/**
 * This function, compress_output, is called just before the output is sent to
 * the client and determines if the output is to be compressed in any manner or
 * not.
 *
 * @param string $p_output The output buffer to be sent to the client.
 * @return string The string to be sent to the client, either compressed or left alone.
 */
function compress_output($p_output) {
	/* Is the length of the data even worth compacting? */
	if (strlen($p_output) >= 1000) {
		/* Get the compression method */
		$gzip = strstr($_SERVER['HTTP_ACCEPT_ENCODING'], 'gzip');
		$deflate = strstr($_SERVER['HTTP_ACCEPT_ENCODING'], 'deflate');
		$encoding = (($gzip) ? 'gzip' : (($deflate) ? 'deflate' : 'none'));

		/* Is this a buggy version of Internet Explorer? */
		if (!strstr($_SERVER['HTTP_USER_AGENT'], 'Opera') && preg_match('/^Mozilla\/4\.0 \(compatible; MSIE ([0-9]\.[0-9])/i', $_SERVER['HTTP_USER_AGENT'], $matches)) {
			$version = floatval($matches[1]);

			/* Is this less than version 6? */
			if ($version < 6)
				$encoding = 'none';
			/* Is this a function IE 6? */
			if ($version == 6 && !strstr($_SERVER['HTTP_USER_AGENT'], 'EV1'))
				$encoding = 'none';
		}
		/* Is this data to be compressed? */
		if ($encoding != 'none') {
			header('Content-Encoding: '.$encoding);
			$p_output = gzencode($p_output, 6, (($gzip) ? FORCE_GZIP : FORCE_DEFLATE));
			header('Content-Length: '.strlen($p_output));
		}
	}
	return ($p_output);
}

ob_start('compress_output');
?>