using System;

namespace AjaxTDG.Output {
	/// <summary>
	///		This class, Utilities, provides the utilities needed when outputting
	///		data to the client.
	/// </summary>
	public class Utilities {
		/// <summary>
		///		This method, CompressPage, detects the encoding types that the
		///		client accepts, and compresses all output to the best compression
		///		type possible.
		/// </summary>
		/// <permission cref="System.Security.PermissionSet">
		///		Public Access
		/// </permission>
		public static void CompressPage() {
			string strEncoding = System.Web.HttpContext.Current.Request.Headers["Accept-Encoding"];
			bool bGZip = strEncoding.Contains("gzip");
			bool bDeflate = strEncoding.Contains("deflate");

			// Does the client accept a coding type to compress with?
			if (!string.IsNullOrEmpty(strEncoding) && (bGZip || bDeflate)) {
				System.Web.HttpResponse Response = System.Web.HttpContext.Current.Response;

				// Does the client use gzip or deflate?
				if (bGZip)
					Response.Filter = new System.IO.Compression.GZipStream(Response.Filter, System.IO.Compression.CompressionMode.Compress);
				else
					Response.Filter = new System.IO.Compression.DeflateStream(Response.Filter, System.IO.Compression.CompressionMode.Compress);
				Response.AppendHeader("Content-Encoding", strEncoding);
			}
		}
	}
}