/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/*
 * Example 4-12, Sarissa in action for XSLT.
 */

/**
 * This function, parseResponse, checks the /request/ object for its /readyState/
 * and /status/ to see if the response is complete, and then takes the XML string
 * returned and does an XSLT transformation using a provided XSL file. It then
 * sets the transformed XML to the /innerHTML/ of the 'list' element.
 */
function parseResponse( ) {
	/* Is the /readyState/ for the /request/ a 4 (complete)? */
	if (request.readyState == 4) {
		/* Is the /status/ from the server 200? */
		if (request.status == 200) {
			var xmlString = request.responseText;
			/* Create a new Sarissa DOM document to hold the XML */
			var xmlDoc = Sarissa.getDomDocument( );
			/* Create a new Sarissa DOM document to hold the XSL */
			var xslDoc = Sarissa.getDomDocument( );

			/* Parse the /responseText/ into the /xmlDoc/ */
			xmlDoc = (new DOMParser( )).parseFromString(xmlString, 'text/xml');
			/* Load the XSL document into the /xslDoc/ */
			xslDoc.async = false;
			xslDoc.load('my.xsl');
			xslDoc.setProperty('SelectionLanguage', 'XPath');
			xslDoc.setproperty('SelectionNamespaces', xmlns:xsl=\'http://www.w3.org/1999/XSL/Transform\'');

			/* Create a new /XSLTProcessor/ object to do the transformation */
			var processor = new XSLTProcessor( );

			processor.importStyleSheet(xslDoc);

			/* Transform the document and set it to the /innerHTML/ of the list */
			var newDoc = processor.transformToDocument(xmlDoc);

			document.getElementById('list').innerHTML = Sarissa.serialize(newDoc);
		} else
			alert('There was a problem retrieving the data: \n' +
		request.statusText);
		request = null;
	}
}