<?php
/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * Example 4-3, A typical script for creating a server response.
 */

/**
 * The Zend framework Db.php library is required for this example.
 */
require_once('Zend/Db.php');
/**
 * The generic db.inc library, containing database connection information such as
 * username, password, server, etc., is required for this example.
 */
require_once('db.inc');

/* Output the XML Prolog so the client can recognize this as XML */
$xml = <<< PROLOG
<?xml version="1.0" encoding="iso-8859-1"?>
PROLOG;

/* Set up the parameters to connect to the database */
$params = array ('host' => $host,
				 'username' => $username,
				 'password' => $password,
				 'dbname' => $db);
try {
	/* Connect to the database */
	$conn = Zend_Db::factory('PDO_MYSQL', $params);

	/* Get the parameter values from the query string */
	$value1 = $conn->quote(($_GET['param1']) ? $_GET['param1'] : '');
	$value2 = $conn->quote(($_GET['param2']) ? $_GET['param2'] : '');
	$value3 = $conn->quote(($_GET['param3']) ? $_GET['param3'] : '');

	/* Create a SQL string and use the values that are protected from SQL injections */
	$sql = 'SELECT * FROM table1 WHERE condition1 = $value1 AND condition2 = $value2 AND condition3 = $value3';
	/* Get the results of the query */
	$result = $conn->query($sql);
	/* Are there results? */
	if ($rows = $result->fetchAll( )) {
		/* Create the response XML string */
		$xml .= '<results>';
		foreach($rows in $row) {
			$xml .= "<result>";
			$xml .= "<column1>{$row['column1']}</column1>";
			$xml .= "<column2>{$row['column2']}</column2>";
			$xml .= "</result>";
		}
		$xml .= '</results>';
	}
} catch (Exception $e) {
	$xml .= '<error>There was an error retrieving the data.</error>';
}
/* Change the header to text/xml so that the client can use the return string as XML */
header("Content-Type: text/xml");
echo $xml;
?>