/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/*
 * Example 7-8, An importNode( ) function for Internet Explorer that mimics what the
 * standard /importNode( )/ method does.
 */

/* Can we use /importNode( )/? [if not, this must be an IE client] */
if (!document.importNode) {
	/*
	 * Create a function that does what should already be part of IE's
	 * implementation of the DOM.
	 */
	/**
	 * This function, importNode, does what should already be part of IE's
	 * implementation of the DOM.
	 *
	 * @param {Object} p_element The element to be imported.
	 * @param {Boolean} p_allChildren Variable to tell the function if all
	 * 		childNodes should also be imported.
	 * @return The newly imported node.
	 * @type Object
	 */
	function importNode(p_element, p_allChildren) {
		/* Find the element's type */
		switch (p_element.nodeType) {
			case 1: /* NODE_ELEMENT */
				var newNode = document.createElement(p_element.nodeName);

				/* Does the element have any attributes to add? */
				if (p_element.attributes && p_element.attributes.length > 0)
					/* Loop through the element's attributes */
				for (var i = 0, il = p_element.attributes.length; i < il;)
					newNode.setAttribute(p_element.attributes[i].nodeName, p_element.getAttribute(p_element.attributes[i++].nodeName));
				/* Are we going after children too, and does the node have any? */
				if (p_allChildren && p_element.childNodes && p_element.childNodes.length > 0)
					/* Loop through the element's childNodes */
					for (var i = 0, il = p_element.childNodes.length; i < il;)
						newNode.appendChild(importNode(p_element.childNodes[i++], p_allChildren));
				return newNode;
				break;
			case 3: /* NODE_TEXT */
			case 4: /* NODE_CDATA_SECTION */
				return document.createTextNode(p_element.nodeValue);
				break;
		}
	};
}