/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This function, createTOC, parses through an XHTML document, taking all header
 * elements within the /content/ of the document, and creating a clickable table
 * of contents to the individual headers that it finds.
 */
function createTOC( ) {
	/*
	 * The table of contents is only concerned with elements contained within
	 * this element.
	 */
	var content = $('content');
	/* Get a node list of all <h1> elements */
	var head1 = content.getElementsByTagName('h1');
	var toc = '<ul>';

	/* Loop through the list of <h1> elements */
	for (var i = 0, il = head1.length; i < il; i++) {
		/* Try to get to the <blockquote> element following the header element */
		var h1 = head1[i].nextSibling;

		/*
		 * Is the node text (whitespace in this case)? If so, try the next element
		 * after this...it should be the <blockquote> element
		 */
		if (h1.nodeType == 3)
			h1 = h1.nextSibling;

		/* Get a node list of all <h2> elements under the <blockquote> element */
		var head2 = h1.getElementsByTagName('h2');

		toc += '<li><a href="#' + head1[i].getAttribute('id') + '">' + head1[i].childNodes[0].nodeValue + '</a>';
		/* Are there any <h2> elements? */
		if (head2.length > 0) {
			toc += '<ul>';
			/* Loop through the list of <h2> elements */
			for (var j = 0, jl = head2.length; j < jl; j++) {

				/*
				 * Try to get to the <blockquote> element following the header
				 * element.
				 */
				var h2 = head2[j].nextSibling;

				/*
				 * Is the node text (whitespace in this case)? If so, try the
				 * next element after this...it should be the <blockquote>
				 * element.
				 */
				if (h2.nodeType == 3)
					h2 = h2.nextSibling;

				/*
				 * Get a node list of all <h3> elements under the <blockquote>
				 * element.
				 */
				var head3 = h2.getElementsByTagName('h3');

				toc += '<li><a href="#' + head2[j].getAttribute('id') + '">' + head2[j].childNodes[0].nodeValue + '</a>';
				/* Are there any <h3> elements? */
				if (head3.length > 0) {
					toc += '<ul>';
					/* Loop through the list of <h3> elements */
					for (var k = 0, kl = head3.length; k < kl; k++) {

						/*
						 * Try to get to the <blockquote> element following the
						 * header element.
						 */
						var h3 = head3[k].nextSibling;

						/*
						 * Is the node text (whitespace in this case)? If so,
						 * try the next element after this...it should be the
						 * <blockquote> element
						 */
						if (h3.nodeType == 3)
							h3 = h3.nextSibling;
						/*
						 * Get a node list of all <h4> elements under the
						 * <blockquote> element.
						 */
						var head4 = h3.getElementsByTagName('h4');

						toc += '<li><a href="#' + head3[k].getAttribute('id') + '">' + head3[k].childNodes[0].nodeValue + '</a>';
						/* Are there any <h4> elements? */
						if (head4.length > 0) {
							toc += '<ul>';
							/* Loop through the list of <h4> elements */
							for (var l = 0, ll = head4.length; l < ll; l++)
								toc += '<li><a href="#' + head4[l].getAttribute('id') + '">' + head4[l].childNodes[0].nodeValue + '</a></li>';
							toc += '</ul>';
						}
						toc += '</li>';
					}
					toc += '</ul>';
				}
				toc += '</li>';
			}
			toc += '</ul>';
		}
		toc += '</li>';
	}
	toc += '</ul>';
	$('toc').innerHTML = toc;
}