/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This function, normalizeElement, takes the passed /p_element/ and strips out
 * all element tags, etc. from the node and any /childNodes/ the element may
 * contain, returning a string with only the text data that was held in the
 * element.
 *
 * @param {Node} p_element The element that is to be normalized.
 * @return Returns the normalized string without element tags or extra whitespace.
 * @type String
 */
function normalizeElement(p_element) {
	/* The variable that will hold the normalized string. */
	var normalized = '';

	/* Loop through the passed element's /childNodes/ to normalize them as well */
	for (var i = 0, il = p_element.childNodes.length; i < il; i++) {
		/* The child element to check */
		var el = p_element.childNodes[i];

		/* Is this node a text node or a cdata section node? */
		if (el.nodeType == document.TEXT_NODE || el.nodeType == document.CDATA_SECTION_NODE || el.nodeType == document.COMMENT_NODE)
			normalized += el.NodeValue;
		/* Is this node an element node and a <br> element? */
		else if (el.nodeType = document.ELEMENT_NODE && el.tagName == 'BR')
			normalized += ' ';
		/* This is something to normalize */
		else
			normalized += normalizeElement(el);
	}
	return (stripSpaces(normalized));
}

/*
 * These regular expressions are used to strip unnecessary white space from
 * the string.
 */
var endWhiteSpace = new RegExp("^\\s*|\\s*$", "g");
var multWhiteSpace = new RegExp("\\s\\s+", "g");

/**
 * This function, stripSpaces, takes the passed /p_string/ variable and using
 * regular expressions, strips all unnecessary white space from the string
 * before returning it.
 *
 * @param {String} p_string The string to be stripped of white space.
 * @return Returns the passed string stripped of unnecessary white space.
 * @type String
 */
function stripSpaces(p_string) {
	p_string = p_string.replace(multWhiteSpace, ' ');
	p_string = p_string.replace(endWhiteSpace, '');
	return (p_string);
}