/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This function, turnDataPage, acts on whatever table (/p_tableId/) is passed,
 * which is the beginning of making this "table independent". It turns off
 * the display of all of the <tbody> elements associated with the table, and
 * then displays the required one based on the passed /p_pageNumber/ variable.
 * Finally, it changes the page number list item that is to be highlighted in
 * association with the table page.
 *
 * @param {String} p_tableId The id of the table to paginate.
 * @param {Integer} p_pageNumber The number of the page that should be displayed.
 * @see Element#setStyle
 * @see Element#removeClassName
 * @see Element#addClassName
 */
function turnDataPage(p_tableId, p_pageNumber) {
	/* Get a list of the <tbody> elements in the table */
	var tbodies = $(p_tableId).getElementsByTagName('tbody');

	/* Loop through the list of <tbody> elements, and hide each one */
	for (var i = 0, il = tbodies.length; i < il; i++)
		tbodies[i].style.display = 'none';
	/* Display the <tbody> element with the correct page number */
	$('p' + p_pageNumber).style.display = 'table-row-group';

	/* Get a list of the <li> elements in the page navigation menu */
	var tableListElements = $('l' + p_pageNumber).parentNode.getElementsByTagName('li');

	/* Loop through the list of <li> elements, and make each one inactive */
	for (var i = 0, il = tableListElements.length; i < il; i++)
		Element.removeClassName(tableListElements[i], 'active');
	/* Activate the <li> element with the correct page number */
	Element.addClassName($('l' + p_pageNumber), 'active');
}