/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This function, sortTable, takes the passed /p_tableId/ and /p_columnId/
 * variables and sends this information to the server so it can do the
 * appropriate sort that is returned to the client. The data from the server
 * is the whole table, because it is faster to build the whole table on the
 * server.
 *
 * @param {String} p_tableId The id of the table to sort.
 * @param {String} p_columnId The id of the column that is to be sorted.
 * @param {Integer} p_pageNumber The number of the page to display.
 */
function sortTable(p_tableId, p_columnId, p_pageNumber) {
	/* Get the direction the sort should go in */
	var sortDirection = (($(p_tableId).lastColumn == p_columnId) ? 1 : 0);
	/* Create the queryString to send to the server */
	var queryString = 'tableId=' + p_tableId + '&columnId=' + p_columnId + '&sort=' + sortDirection + '&page=' + p_pageNumber;

	/* Record the column that is sorted */
	$(p_tableId).lastColumn = p_columnId;
	/*
	 * Make the XMLHttpRequest to the server, and place the /responseText/ into the
	 * /innerHTML/ of the table wrapper (/parentNode/).
	 */
	new Ajax.Request('sortTable.php', {
		parameters: queryString,
		method: 'post',
		onSuccess: function(xhrResponse) {
			$(tableId).parentNode.innerHTML = xhrResponse.responseText;
		},
		onFailure: function(xhrResponse) {
			$(tableId).parentNode.innerHTML = xhrResponse.statusText;
		}
	});
}