/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This function, openPageInDIV, makes an XMLHttpRequest to the passed /p_page/
 * parameter and the <body> of the page is then imported and appended into the
 * passed /p_div/ parameter. Using the custom document._importNode( ) method
 * ensures with most browsers that any attribute events that are contained in the
 * <body> will fire when called upon. For other browsers, like Internet Explorer,
 * setting the /p_div/'s /innerHTML/ equal to itself does the trick.
 *
 * @param {String} p_page The string filename of the page to get data from.
 * @param {String} p_div The string /id/ of the <div> element to put the data into.
 * @return Returns false, so that the <a> element will not attempt to leave the page.
 * @type Boolean
 */
function openPageInDIV(p_page, p_div) {
	var where = $(p_div);

	new Ajax.Request(p_page, {
		method: 'get',
		onSuccess: function(xhrResponse) {
			var newNode = null, importedElement = null;

			/* Get the body element...all of its children are what we are after */
			newNode = xhrResponse.responseXML.getElementsByTagName('body')[0].childNodes[0];
			/* was there any whitespace in the document? */
			if (newNode.nodeType != document.ELEMENT_NODE)
				newNode = newNode.nextSibling;
			/* Is there a node to import? */
			if (newNode) {
				importedNode = document._importNode(newNode, true);
				where.appendChild(importedNode);
				if (!document.importNode)
					where.innerHTML = where.innerHTML;
			}
		},
		onFailure: function(xhrResponse) {
			where.appendChild(document.createTextNode(xhrResponse .statusText));
		}
	});
	return (false);
}