/* This example is from the book _Ajax: The Definitive Guide_ by Anthony T. Holdener III.
 * Written by Anthony T. Holdener III.  Copyright (C) 2008 O'Reilly Media, Inc.
 * You may study, use, modify, and distribute this example for any purpose.
 * This example is provided WITHOUT WARRANTY either expressed or implied.
 */
/**
 * This method, _importNode, is a replacement for the DOM /document.importNode( )/
 * method. To ensure that any attribute events that are contained in the document
 * are fired when requested, it should go through this method instead. The standard
 * /importNode( )/ does not set the event handlers for events set as attributes in an
 * imported document, nor does it place style toward elements that should do such
 * things in the browser. An additional requirement is necessary for browsers like
 * Internet Explorer after the document has been imported - the /innerHTML/ of the
 * document where the import took place must be set equal to itself to invoke the
 * HTML Parse in the browser which will attach the event handlers.
 *
 * document.getElementById('myDiv').innerHTML = document.getElementById('myDiv').innerHTML;
 *
 * @param {Node} p_node The node to import into the main document,
 * @param {Boolean} p_allChildren The indicator of whether or not to include child
 * 		nodes in the import.
 * @return Returns a copy of the imported node, now as a part of the main document.
 * @type Node
 */
document._importNode = function(p_node, p_allChildren) {
	/* Find the node type to import */
	switch (p_node.nodeType) {
		case document.ELEMENT_NODE:
			/* Create a new element */
			var newNode = document.createElement(p_node.nodeName);

			/* Does the node have any attributes to add? */
			if (p_node.attributes && p_node.attributes.length > 0)
				/* Add all of the attributes */
				for (var i = 0, il = p_node.attributes.length; i < il;)
					newNode.setAttribute(p_node.attributes[i].nodeName, p_node.getAttribute(p_node.attributes[i++].nodeName));
			/* Are we going after children too, and does the node have any? */
			if (p_allChildren && p_node.childNodes && p_node.childNodes.length > 0)
				/* Recursively get all of the child nodes */
				for (var i = 0, il = p_node.childNodes.length; i < il;)
					newNode.appendChild(document._importNode(p_node.childNodes[i++], p_allChildren));
			return newNode;
			break;
		case document.TEXT_NODE:
		case document.CDATA_SECTION_NODE:
		case document.COMMENT_NODE:
			return document.createTextNode(p_node.nodeValue);
		break;
	}
};